summaryrefslogtreecommitdiff
path: root/transmitters
diff options
context:
space:
mode:
authorOlivier CrĂȘte <olivier.crete@collabora.com>2011-10-11 14:55:29 -0400
committerOlivier CrĂȘte <olivier.crete@collabora.com>2011-10-11 16:14:07 -0400
commite33572c56e93ad1a0f644047f30fc23ab5e01372 (patch)
tree2347860066da7fa0c91df89dc86a06e4e012236c /transmitters
parent449a53f65146448d70f761cc1257171702c83db4 (diff)
downloadfarstream-e33572c56e93ad1a0f644047f30fc23ab5e01372.tar.gz
Rename Farsight 2 to Farstream
Diffstat (limited to 'transmitters')
-rw-r--r--transmitters/Makefile.am4
-rw-r--r--transmitters/multicast/Makefile.am12
-rw-r--r--transmitters/multicast/fs-multicast-stream-transmitter.c8
-rw-r--r--transmitters/multicast/fs-multicast-stream-transmitter.h8
-rw-r--r--transmitters/multicast/fs-multicast-transmitter.c10
-rw-r--r--transmitters/multicast/fs-multicast-transmitter.h6
-rw-r--r--transmitters/nice/Makefile.am12
-rw-r--r--transmitters/nice/fs-nice-agent.c2
-rw-r--r--transmitters/nice/fs-nice-agent.h6
-rw-r--r--transmitters/nice/fs-nice-stream-transmitter.c2
-rw-r--r--transmitters/nice/fs-nice-stream-transmitter.h8
-rw-r--r--transmitters/nice/fs-nice-transmitter.c10
-rw-r--r--transmitters/nice/fs-nice-transmitter.h6
-rw-r--r--transmitters/rawudp/Makefile.am12
-rw-r--r--transmitters/rawudp/fs-rawudp-component.c8
-rw-r--r--transmitters/rawudp/fs-rawudp-component.h8
-rw-r--r--transmitters/rawudp/fs-rawudp-stream-transmitter.c8
-rw-r--r--transmitters/rawudp/fs-rawudp-stream-transmitter.h8
-rw-r--r--transmitters/rawudp/fs-rawudp-transmitter.c10
-rw-r--r--transmitters/rawudp/fs-rawudp-transmitter.h6
-rw-r--r--transmitters/shm/Makefile.am12
-rw-r--r--transmitters/shm/fs-shm-stream-transmitter.c10
-rw-r--r--transmitters/shm/fs-shm-stream-transmitter.h8
-rw-r--r--transmitters/shm/fs-shm-transmitter.c10
-rw-r--r--transmitters/shm/fs-shm-transmitter.h6
25 files changed, 100 insertions, 100 deletions
diff --git a/transmitters/Makefile.am b/transmitters/Makefile.am
index 0a91f817..dd9d02d6 100644
--- a/transmitters/Makefile.am
+++ b/transmitters/Makefile.am
@@ -1,3 +1,3 @@
-SUBDIRS = $(FS2_TRANSMITTER_PLUGINS_SELECTED)
-DIST_SUBDIRS = $(FS2_TRANSMITTER_PLUGINS_ALL)
+SUBDIRS = $(FS_TRANSMITTER_PLUGINS_SELECTED)
+DIST_SUBDIRS = $(FS_TRANSMITTER_PLUGINS_ALL)
diff --git a/transmitters/multicast/Makefile.am b/transmitters/multicast/Makefile.am
index 36252d39..80b5ffd3 100644
--- a/transmitters/multicast/Makefile.am
+++ b/transmitters/multicast/Makefile.am
@@ -1,5 +1,5 @@
-plugindir = $(FS2_PLUGIN_PATH)
+plugindir = $(FS_PLUGIN_PATH)
plugin_LTLIBRARIES = libmulticast-transmitter.la
@@ -10,14 +10,14 @@ libmulticast_transmitter_la_SOURCES = \
# flags used to compile this plugin
libmulticast_transmitter_la_CFLAGS = \
- $(FS2_INTERNAL_CFLAGS) \
- $(FS2_CFLAGS) \
+ $(FS_INTERNAL_CFLAGS) \
+ $(FS_CFLAGS) \
$(GST_PLUGINS_BASE_CFLAGS) \
$(GST_CFLAGS)
-libmulticast_transmitter_la_LDFLAGS = $(FS2_PLUGIN_LDFLAGS)
+libmulticast_transmitter_la_LDFLAGS = $(FS_PLUGIN_LDFLAGS)
libmulticast_transmitter_la_LIBADD = \
- $(top_builddir)/gst-libs/gst/farsight/libgstfarsight-0.10.la \
- $(FS2_LIBS) \
+ $(top_builddir)/gst-libs/gst/farstream/libgstfarstream-0.10.la \
+ $(FS_LIBS) \
$(GST_BASE_LIBS) \
$(GST_LIBS)
diff --git a/transmitters/multicast/fs-multicast-stream-transmitter.c b/transmitters/multicast/fs-multicast-stream-transmitter.c
index 264e6d7e..76ac4742 100644
--- a/transmitters/multicast/fs-multicast-stream-transmitter.c
+++ b/transmitters/multicast/fs-multicast-stream-transmitter.c
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight Multicast UDP Stream Transmitter
+ * Farstream - Farstream Multicast UDP Stream Transmitter
*
* Copyright 2007 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007 Nokia Corp.
*
- * fs-multicast-stream-transmitter.c - A Farsight Multiast UDP stream transmitter
+ * fs-multicast-stream-transmitter.c - A Farstream Multiast UDP stream transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -60,8 +60,8 @@
#include "fs-multicast-stream-transmitter.h"
#include "fs-multicast-transmitter.h"
-#include <gst/farsight/fs-candidate.h>
-#include <gst/farsight/fs-conference.h>
+#include <gst/farstream/fs-candidate.h>
+#include <gst/farstream/fs-conference.h>
#include <gst/gst.h>
diff --git a/transmitters/multicast/fs-multicast-stream-transmitter.h b/transmitters/multicast/fs-multicast-stream-transmitter.h
index 094999cb..87f2dd92 100644
--- a/transmitters/multicast/fs-multicast-stream-transmitter.h
+++ b/transmitters/multicast/fs-multicast-stream-transmitter.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight Multicast UDP Stream Transmitter
+ * Farstream - Farstream Multicast UDP Stream Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
- * fs-multicast stream-transmitter.h - A Farsight Multicast UDP stream transmitter
+ * fs-multicast stream-transmitter.h - A Farstream Multicast UDP stream transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -28,8 +28,8 @@
#include <glib.h>
#include <glib-object.h>
-#include <gst/farsight/fs-stream-transmitter.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-stream-transmitter.h>
+#include <gst/farstream/fs-plugin.h>
#include "fs-multicast-transmitter.h"
G_BEGIN_DECLS
diff --git a/transmitters/multicast/fs-multicast-transmitter.h b/transmitters/multicast/fs-multicast-transmitter.h
index 37c0b6b0..07c359cc 100644
--- a/transmitters/multicast/fs-multicast-transmitter.h
+++ b/transmitters/multicast/fs-multicast-transmitter.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight Multicast UDP Transmitter
+ * Farstream - Farstream Multicast UDP Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
- * fs-multicast-transmitter.h - A Farsight Multicast UDP transmitter
+ * fs-multicast-transmitter.h - A Farstream Multicast UDP transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@
#ifndef __FS_MULTICAST_TRANSMITTER_H__
#define __FS_MULTICAST_TRANSMITTER_H__
-#include <gst/farsight/fs-transmitter.h>
+#include <gst/farstream/fs-transmitter.h>
#include <gst/gst.h>
diff --git a/transmitters/nice/Makefile.am b/transmitters/nice/Makefile.am
index ef9dfec9..64ef937e 100644
--- a/transmitters/nice/Makefile.am
+++ b/transmitters/nice/Makefile.am
@@ -1,5 +1,5 @@
-plugindir = $(FS2_PLUGIN_PATH)
+plugindir = $(FS_PLUGIN_PATH)
plugin_LTLIBRARIES = libnice-transmitter.la
@@ -11,15 +11,15 @@ libnice_transmitter_la_SOURCES = \
# flags used to compile this plugin
libnice_transmitter_la_CFLAGS = \
- $(FS2_INTERNAL_CFLAGS) \
- $(FS2_CFLAGS) \
+ $(FS_INTERNAL_CFLAGS) \
+ $(FS_CFLAGS) \
$(GST_PLUGINS_BASE_CFLAGS) \
$(GST_CFLAGS) \
$(NICE_CFLAGS)
-libnice_transmitter_la_LDFLAGS = $(FS2_PLUGIN_LDFLAGS)
+libnice_transmitter_la_LDFLAGS = $(FS_PLUGIN_LDFLAGS)
libnice_transmitter_la_LIBADD = \
- $(top_builddir)/gst-libs/gst/farsight/libgstfarsight-0.10.la \
- $(FS2_LIBS) \
+ $(top_builddir)/gst-libs/gst/farstream/libgstfarstream-0.10.la \
+ $(FS_LIBS) \
$(GST_BASE_LIBS) \
$(GST_LIBS) \
$(NICE_LIBS)
diff --git a/transmitters/nice/fs-nice-agent.c b/transmitters/nice/fs-nice-agent.c
index 3b350e25..1e1e2c69 100644
--- a/transmitters/nice/fs-nice-agent.c
+++ b/transmitters/nice/fs-nice-agent.c
@@ -32,7 +32,7 @@
#include "config.h"
#endif
-#include <gst/farsight/fs-conference.h>
+#include <gst/farstream/fs-conference.h>
#include "fs-nice-transmitter.h"
#include "fs-nice-agent.h"
diff --git a/transmitters/nice/fs-nice-agent.h b/transmitters/nice/fs-nice-agent.h
index eed41cc3..6e634103 100644
--- a/transmitters/nice/fs-nice-agent.h
+++ b/transmitters/nice/fs-nice-agent.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight libnice Transmitter agent object
+ * Farstream - Farstream libnice Transmitter agent object
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
- * fs-nice-agent.h - A Farsight libnice transmitter agent object
+ * fs-nice-agent.h - A Farstream libnice transmitter agent object
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,7 @@
#define __FS_NICE_AGENT_H__
#include <glib-object.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-plugin.h>
G_BEGIN_DECLS
diff --git a/transmitters/nice/fs-nice-stream-transmitter.c b/transmitters/nice/fs-nice-stream-transmitter.c
index fdc5a240..0e7782e0 100644
--- a/transmitters/nice/fs-nice-stream-transmitter.c
+++ b/transmitters/nice/fs-nice-stream-transmitter.c
@@ -38,7 +38,7 @@
#include "fs-nice-transmitter.h"
#include "fs-nice-agent.h"
-#include <gst/farsight/fs-conference.h>
+#include <gst/farstream/fs-conference.h>
#include <gst/gst.h>
diff --git a/transmitters/nice/fs-nice-stream-transmitter.h b/transmitters/nice/fs-nice-stream-transmitter.h
index 8a65b548..b40e02ee 100644
--- a/transmitters/nice/fs-nice-stream-transmitter.h
+++ b/transmitters/nice/fs-nice-stream-transmitter.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight libnice Stream Transmitter
+ * Farstream - Farstream libnice Stream Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
- * fs-nice-stream-transmitter.h - A Farsight libnice based stream transmitter
+ * fs-nice-stream-transmitter.h - A Farstream libnice based stream transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -28,8 +28,8 @@
#include <glib.h>
#include <glib-object.h>
-#include <gst/farsight/fs-stream-transmitter.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-stream-transmitter.h>
+#include <gst/farstream/fs-plugin.h>
#include "fs-nice-transmitter.h"
G_BEGIN_DECLS
diff --git a/transmitters/nice/fs-nice-transmitter.h b/transmitters/nice/fs-nice-transmitter.h
index 74aa3c9c..a39ae610 100644
--- a/transmitters/nice/fs-nice-transmitter.h
+++ b/transmitters/nice/fs-nice-transmitter.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight libnice Transmitter
+ * Farstream - Farstream libnice Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
- * fs-nice-transmitter.h - A Farsight libnice transmitter
+ * fs-nice-transmitter.h - A Farstream libnice transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@
#ifndef __FS_NICE_TRANSMITTER_H__
#define __FS_NICE_TRANSMITTER_H__
-#include <gst/farsight/fs-transmitter.h>
+#include <gst/farstream/fs-transmitter.h>
#include <gst/gst.h>
#include <agent.h>
diff --git a/transmitters/rawudp/Makefile.am b/transmitters/rawudp/Makefile.am
index 861ecf40..d637da85 100644
--- a/transmitters/rawudp/Makefile.am
+++ b/transmitters/rawudp/Makefile.am
@@ -1,5 +1,5 @@
-plugindir = $(FS2_PLUGIN_PATH)
+plugindir = $(FS_PLUGIN_PATH)
plugin_LTLIBRARIES = librawudp-transmitter.la
@@ -16,16 +16,16 @@ nodist_librawudp_transmitter_la_SOURCES = \
# flags used to compile this plugin
librawudp_transmitter_la_CFLAGS = \
- $(FS2_INTERNAL_CFLAGS) \
- $(FS2_CFLAGS) \
+ $(FS_INTERNAL_CFLAGS) \
+ $(FS_CFLAGS) \
$(GST_PLUGINS_BASE_CFLAGS) \
$(GST_CFLAGS) \
$(NICE_CFLAGS) \
$(GUPNP_CFLAGS)
-librawudp_transmitter_la_LDFLAGS = $(FS2_PLUGIN_LDFLAGS)
+librawudp_transmitter_la_LDFLAGS = $(FS_PLUGIN_LDFLAGS)
librawudp_transmitter_la_LIBADD = \
- $(top_builddir)/gst-libs/gst/farsight/libgstfarsight-0.10.la \
- $(FS2_LIBS) \
+ $(top_builddir)/gst-libs/gst/farstream/libgstfarstream-0.10.la \
+ $(FS_LIBS) \
$(GST_PLUGINS_BASE_LIBS) \
$(GST_LIBS) \
$(NICE_LIBS) \
diff --git a/transmitters/rawudp/fs-rawudp-component.h b/transmitters/rawudp/fs-rawudp-component.h
index c66f1bb1..317eb4b8 100644
--- a/transmitters/rawudp/fs-rawudp-component.h
+++ b/transmitters/rawudp/fs-rawudp-component.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight RAW UDP with STUN Component Transmitter
+ * Farstream - Farstream RAW UDP with STUN Component Transmitter
*
* Copyright 2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2008 Nokia Corp.
*
- * fs-rawudp-component.h - A Farsight UDP component transmitter with STUN
+ * fs-rawudp-component.h - A Farstream UDP component transmitter with STUN
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -28,8 +28,8 @@
#include <glib.h>
#include <glib-object.h>
-#include <gst/farsight/fs-stream-transmitter.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-stream-transmitter.h>
+#include <gst/farstream/fs-plugin.h>
#include "fs-rawudp-transmitter.h"
G_BEGIN_DECLS
diff --git a/transmitters/rawudp/fs-rawudp-stream-transmitter.c b/transmitters/rawudp/fs-rawudp-stream-transmitter.c
index 86f4f33a..5d2f0d0f 100644
--- a/transmitters/rawudp/fs-rawudp-stream-transmitter.c
+++ b/transmitters/rawudp/fs-rawudp-stream-transmitter.c
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight RAW UDP with STUN Stream Transmitter
+ * Farstream - Farstream RAW UDP with STUN Stream Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008x Nokia Corp.
*
- * fs-rawudp-transmitter.c - A Farsight UDPs stream transmitter with STUN
+ * fs-rawudp-transmitter.c - A Farstream UDPs stream transmitter with STUN
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -66,8 +66,8 @@
#include "fs-rawudp-component.h"
-#include <gst/farsight/fs-candidate.h>
-#include <gst/farsight/fs-conference.h>
+#include <gst/farstream/fs-candidate.h>
+#include <gst/farstream/fs-conference.h>
#ifdef HAVE_GUPNP
#include <libgupnp-igd/gupnp-simple-igd-thread.h>
diff --git a/transmitters/rawudp/fs-rawudp-stream-transmitter.h b/transmitters/rawudp/fs-rawudp-stream-transmitter.h
index 0fbfe4c8..8e0698b0 100644
--- a/transmitters/rawudp/fs-rawudp-stream-transmitter.h
+++ b/transmitters/rawudp/fs-rawudp-stream-transmitter.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight RAW UDP with STUN Stream Transmitter
+ * Farstream - Farstream RAW UDP with STUN Stream Transmitter
*
* Copyright 2007 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007 Nokia Corp.
*
- * fs-stream-transmitter.h - A Farsight UDP stream transmitter with STUN
+ * fs-stream-transmitter.h - A Farstream UDP stream transmitter with STUN
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -28,8 +28,8 @@
#include <glib.h>
#include <glib-object.h>
-#include <gst/farsight/fs-stream-transmitter.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-stream-transmitter.h>
+#include <gst/farstream/fs-plugin.h>
#include "fs-rawudp-transmitter.h"
G_BEGIN_DECLS
diff --git a/transmitters/rawudp/fs-rawudp-transmitter.h b/transmitters/rawudp/fs-rawudp-transmitter.h
index 151444a8..723bd06a 100644
--- a/transmitters/rawudp/fs-rawudp-transmitter.h
+++ b/transmitters/rawudp/fs-rawudp-transmitter.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight RAW UDP with STUN Transmitter
+ * Farstream - Farstream RAW UDP with STUN Transmitter
*
* Copyright 2007 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007 Nokia Corp.
*
- * fs-rawudp-transmitter.h - A Farsight UDP transmitter with STUN
+ * fs-rawudp-transmitter.h - A Farstream UDP transmitter with STUN
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@
#ifndef __FS_RAWUDP_TRANSMITTER_H__
#define __FS_RAWUDP_TRANSMITTER_H__
-#include <gst/farsight/fs-transmitter.h>
+#include <gst/farstream/fs-transmitter.h>
#include <gst/netbuffer/gstnetbuffer.h>
diff --git a/transmitters/shm/Makefile.am b/transmitters/shm/Makefile.am
index be1a672c..c656a3d7 100644
--- a/transmitters/shm/Makefile.am
+++ b/transmitters/shm/Makefile.am
@@ -1,5 +1,5 @@
-plugindir = $(FS2_PLUGIN_PATH)
+plugindir = $(FS_PLUGIN_PATH)
plugin_LTLIBRARIES = libshm-transmitter.la
@@ -10,14 +10,14 @@ libshm_transmitter_la_SOURCES = \
# flags used to compile this plugin
libshm_transmitter_la_CFLAGS = \
- $(FS2_INTERNAL_CFLAGS) \
- $(FS2_CFLAGS) \
+ $(FS_INTERNAL_CFLAGS) \
+ $(FS_CFLAGS) \
$(GST_PLUGINS_BASE_CFLAGS) \
$(GST_CFLAGS)
-libshm_transmitter_la_LDFLAGS = $(FS2_PLUGIN_LDFLAGS)
+libshm_transmitter_la_LDFLAGS = $(FS_PLUGIN_LDFLAGS)
libshm_transmitter_la_LIBADD = \
- $(top_builddir)/gst-libs/gst/farsight/libgstfarsight-0.10.la \
- $(FS2_LIBS) \
+ $(top_builddir)/gst-libs/gst/farstream/libgstfarstream-0.10.la \
+ $(FS_LIBS) \
$(GST_BASE_LIBS) \
$(GST_LIBS)
diff --git a/transmitters/shm/fs-shm-stream-transmitter.h b/transmitters/shm/fs-shm-stream-transmitter.h
index ad824894..f44b3170 100644
--- a/transmitters/shm/fs-shm-stream-transmitter.h
+++ b/transmitters/shm/fs-shm-stream-transmitter.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight Shared Memory Stream Transmitter
+ * Farstream - Farstream Shared Memory Stream Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
- * fs-shm-stream-transmitter.h - A Farsight Shared Memory stream transmitter
+ * fs-shm-stream-transmitter.h - A Farstream Shared Memory stream transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -28,8 +28,8 @@
#include <glib.h>
#include <glib-object.h>
-#include <gst/farsight/fs-stream-transmitter.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-stream-transmitter.h>
+#include <gst/farstream/fs-plugin.h>
#include "fs-shm-transmitter.h"
G_BEGIN_DECLS
diff --git a/transmitters/shm/fs-shm-transmitter.h b/transmitters/shm/fs-shm-transmitter.h
index 26753ac6..e483068c 100644
--- a/transmitters/shm/fs-shm-transmitter.h
+++ b/transmitters/shm/fs-shm-transmitter.h
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight Shared Memory Transmitter
+ * Farstream - Farstream Shared Memory Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
- * fs-shm-transmitter.h - A Farsight Shared Memory transmitter
+ * fs-shm-transmitter.h - A Farstream Shared Memory transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@
#ifndef __FS_SHM_TRANSMITTER_H__
#define __FS_SHM_TRANSMITTER_H__
-#include <gst/farsight/fs-transmitter.h>
+#include <gst/farstream/fs-transmitter.h>
#include <gst/gst.h>
diff --git a/transmitters/multicast/fs-multicast-transmitter.c b/transmitters/multicast/fs-multicast-transmitter.c
index 14f6a741..ae3fcb2c 100644
--- a/transmitters/multicast/fs-multicast-transmitter.c
+++ b/transmitters/multicast/fs-multicast-transmitter.c
@@ -1,11 +1,11 @@
/*
* Farsight2 - Farsight Multicast UDP Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
* fs-multicast-transmitter.c - A Farsight multicast UDP transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -37,8 +37,8 @@
#include "fs-multicast-transmitter.h"
#include "fs-multicast-stream-transmitter.h"
-#include <gst/farsight/fs-conference.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-conference.h>
+#include <gst/farstream/fs-plugin.h>
#include <string.h>
#include <sys/types.h>
@@ -161,7 +161,7 @@ fs_multicast_transmitter_register_type (FsPlugin *module)
GST_DEBUG_CATEGORY_INIT (fs_multicast_transmitter_debug,
"fsmulticasttransmitter", 0,
- "Farsight multicast UDP transmitter");
+ "Farstream multicast UDP transmitter");
fs_multicast_stream_transmitter_register_type (module);
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight Multicast UDP Transmitter
+ * Farstream - Farstream Multicast UDP Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
@@ -1,11 +1,11 @@
* Copyright 2007-2008 Nokia Corp.
*
- * fs-multicast-transmitter.c - A Farsight multicast UDP transmitter
+ * fs-multicast-transmitter.c - A Farstream multicast UDP transmitter
*
* This library is free software; you can redistribute it and/or
diff --git a/transmitters/nice/fs-nice-transmitter.c b/transmitters/nice/fs-nice-transmitter.c
index 33d3c366..48773e19 100644
--- a/transmitters/nice/fs-nice-transmitter.c
+++ b/transmitters/nice/fs-nice-transmitter.c
@@ -1,11 +1,11 @@
/*
* Farsight2 - Farsight libnice Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
* fs-nice-transmitter.c - A Farsight libnice transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -39,8 +39,8 @@
#include "fs-nice-stream-transmitter.h"
#include "fs-nice-agent.h"
-#include <gst/farsight/fs-conference.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-conference.h>
+#include <gst/farstream/fs-plugin.h>
#include <agent.h>
@@ -142,7 +142,7 @@ fs_nice_transmitter_register_type (FsPlugin *module)
GST_DEBUG_CATEGORY_INIT (fs_nice_transmitter_debug,
"fsnicetransmitter", 0,
- "Farsight libnice transmitter");
+ "Farstream libnice transmitter");
fs_nice_stream_transmitter_register_type (module);
fs_nice_agent_register_type (module);
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight libnice Transmitter
+ * Farstream - Farstream libnice Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
@@ -1,11 +1,11 @@
* Copyright 2007-2008 Nokia Corp.
*
- * fs-nice-transmitter.c - A Farsight libnice transmitter
+ * fs-nice-transmitter.c - A Farstream libnice transmitter
*
* This library is free software; you can redistribute it and/or
diff --git a/transmitters/rawudp/fs-rawudp-component.c b/transmitters/rawudp/fs-rawudp-component.c
index 0b04df30..9e28199a 100644
--- a/transmitters/rawudp/fs-rawudp-component.c
+++ b/transmitters/rawudp/fs-rawudp-component.c
@@ -1,11 +1,11 @@
/*
* Farsight2 - Farsight RAW UDP with STUN Component Transmitter
*
* Copyright 2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2008 Nokia Corp.
*
* fs-rawudp-transmitter.c - A Farsight UDP transmitter with STUN
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -37,7 +37,7 @@
#include <nice/address.h>
#include <nice/interfaces.h>
-#include <gst/farsight/fs-conference.h>
+#include <gst/farstream/fs-conference.h>
#include <gst/netbuffer/gstnetbuffer.h>
@@ -1229,7 +1229,7 @@ fs_rawudp_component_gather_local_candidates (FsRawUdpComponent *self,
gupnp_simple_igd_add_port (GUPNP_SIMPLE_IGD (self->priv->upnp_igd),
"UDP", port, ip, port, self->priv->upnp_mapping_timeout,
- "Farsight Raw UDP transmitter " PACKAGE_VERSION);
+ "Farstream Raw UDP transmitter " PACKAGE_VERSION);
if (self->priv->upnp_discovery)
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight RAW UDP with STUN Component Transmitter
+ * Farstream - Farstream RAW UDP with STUN Component Transmitter
*
* Copyright 2008 Collabora Ltd.
@@ -1,11 +1,11 @@
* Copyright 2008 Nokia Corp.
*
- * fs-rawudp-transmitter.c - A Farsight UDP transmitter with STUN
+ * fs-rawudp-transmitter.c - A Farstream UDP transmitter with STUN
*
* This library is free software; you can redistribute it and/or
diff --git a/transmitters/rawudp/fs-rawudp-transmitter.c b/transmitters/rawudp/fs-rawudp-transmitter.c
index 5e8a7174..111e7392 100644
--- a/transmitters/rawudp/fs-rawudp-transmitter.c
+++ b/transmitters/rawudp/fs-rawudp-transmitter.c
@@ -1,11 +1,11 @@
/*
* Farsight2 - Farsight RAW UDP with STUN Transmitter
*
* Copyright 2007 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007 Nokia Corp.
*
* fs-rawudp-transmitter.h - A Farsight UDP transmitter with STUN
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -37,8 +37,8 @@
#include "fs-rawudp-transmitter.h"
#include "fs-rawudp-stream-transmitter.h"
-#include <gst/farsight/fs-conference.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-conference.h>
+#include <gst/farstream/fs-plugin.h>
#include <string.h>
#include <sys/types.h>
@@ -164,7 +164,7 @@ fs_rawudp_transmitter_register_type (FsPlugin *module)
GST_DEBUG_CATEGORY_INIT (fs_rawudp_transmitter_debug,
"fsrawudptransmitter", 0,
- "Farsight raw UDP transmitter");
+ "Farstream raw UDP transmitter");
fs_rawudp_stream_transmitter_register_type (module);
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight RAW UDP with STUN Transmitter
+ * Farstream - Farstream RAW UDP with STUN Transmitter
*
* Copyright 2007 Collabora Ltd.
@@ -1,11 +1,11 @@
* Copyright 2007 Nokia Corp.
*
- * fs-rawudp-transmitter.h - A Farsight UDP transmitter with STUN
+ * fs-rawudp-transmitter.h - A Farstream UDP transmitter with STUN
*
* This library is free software; you can redistribute it and/or
diff --git a/transmitters/shm/fs-shm-stream-transmitter.c b/transmitters/shm/fs-shm-stream-transmitter.c
index f768c60d..8ef3d742 100644
--- a/transmitters/shm/fs-shm-stream-transmitter.c
+++ b/transmitters/shm/fs-shm-stream-transmitter.c
@@ -1,11 +1,11 @@
/*
* Farsight2 - Farsight Shared Memory Stream Transmitter
*
* Copyright 2009 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2009 Nokia Corp.
*
* fs-shm-stream-transmitter.c - A Farsight Shared memory stream transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -66,8 +66,8 @@
#include "fs-shm-stream-transmitter.h"
#include "fs-shm-transmitter.h"
-#include <gst/farsight/fs-candidate.h>
-#include <gst/farsight/fs-conference.h>
+#include <gst/farstream/fs-candidate.h>
+#include <gst/farstream/fs-conference.h>
#include <gst/gst.h>
@@ -558,7 +558,7 @@ fs_shm_stream_transmitter_gather_local_candidates (
gchar *socket_dir;
socket_dir = g_build_filename (g_get_tmp_dir (),
- "farsight-shm-XXXXXX", NULL);
+ "farstream-shm-XXXXXX", NULL);
if (mkdtemp (socket_dir) == NULL)
return FALSE;
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight Shared Memory Stream Transmitter
+ * Farstream - Farstream Shared Memory Stream Transmitter
*
* Copyright 2009 Collabora Ltd.
@@ -1,11 +1,11 @@
* Copyright 2009 Nokia Corp.
*
- * fs-shm-stream-transmitter.c - A Farsight Shared memory stream transmitter
+ * fs-shm-stream-transmitter.c - A Farstream Shared memory stream transmitter
*
* This library is free software; you can redistribute it and/or
diff --git a/transmitters/shm/fs-shm-transmitter.c b/transmitters/shm/fs-shm-transmitter.c
index edaac2bf..d1b15740 100644
--- a/transmitters/shm/fs-shm-transmitter.c
+++ b/transmitters/shm/fs-shm-transmitter.c
@@ -1,11 +1,11 @@
/*
* Farsight2 - Farsight Shm UDP Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
* @author: Olivier Crete <olivier.crete@collabora.co.uk>
* Copyright 2007-2008 Nokia Corp.
*
* fs-shm-transmitter.c - A Farsight shm UDP transmitter
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
@@ -37,8 +37,8 @@
#include "fs-shm-transmitter.h"
#include "fs-shm-stream-transmitter.h"
-#include <gst/farsight/fs-conference.h>
-#include <gst/farsight/fs-plugin.h>
+#include <gst/farstream/fs-conference.h>
+#include <gst/farstream/fs-plugin.h>
#include <string.h>
@@ -234,7 +234,7 @@ fs_shm_transmitter_register_type (FsPlugin *module)
GST_DEBUG_CATEGORY_INIT (fs_shm_transmitter_debug,
"fsshmtransmitter", 0,
- "Farsight shm UDP transmitter");
+ "Farstream shm UDP transmitter");
fs_shm_stream_transmitter_register_type (module);
@@ -1,11 +1,11 @@
/*
- * Farsight2 - Farsight Shm UDP Transmitter
+ * Farstream - Farstream Shm UDP Transmitter
*
* Copyright 2007-2008 Collabora Ltd.
@@ -1,11 +1,11 @@
* Copyright 2007-2008 Nokia Corp.
*
- * fs-shm-transmitter.c - A Farsight shm UDP transmitter
+ * fs-shm-transmitter.c - A Farstream shm UDP transmitter
*
* This library is free software; you can redistribute it and/or